stat

Struct stat 

#[repr(C)]
pub struct stat {
Show 14 fields pub st_dev: dev_t, pub st_ino: ino_t, pub st_nlink: nlink_t, pub st_mode: mode_t, pub st_uid: uid_t, pub st_gid: gid_t, pub st_rdev: dev_t, pub st_size: off_t, pub st_blksize: blksize_t, pub st_blocks: blkcnt_t, pub st_atim: timespec, pub st_mtim: timespec, pub st_ctim: timespec, pub _pad: [c_char; 24],
}
Fields

st_dev: dev_t

Device ID of device containing file.

st_ino: ino_t

File serial number.

st_nlink: nlink_t

Number of hard links to the file.

st_mode: mode_t

Mode of file.

st_uid: uid_t

User ID of file.

st_gid: gid_t

Group ID of file.

st_rdev: dev_t

Device ID (if file is character or block special).

st_size: off_t

For regular files, the file size in bytes. For symbolic links, the length in bytes of the pathname contained in the symbolic link. For a shared or typed memory object, the length in bytes. For other file types, the use of this field is unspecified.

st_blksize: blksize_t

A file system-specific preferred I/O block size for this object. In some file system types, this may vary from file to file.

st_blocks: blkcnt_t

Number of blocks allocated for this object.

st_atim: timespec

Last data access timestamp.

st_mtim: timespec

Last data modification timestamp.

st_ctim: timespec

Last file status change timestamp.

_pad: [c_char; 24]