#[repr(C)]pub struct stat {Show 14 fields
pub st_dev: dev_t,
pub st_ino: ino_t,
pub st_nlink: nlink_t,
pub st_mode: mode_t,
pub st_uid: uid_t,
pub st_gid: gid_t,
pub st_rdev: dev_t,
pub st_size: off_t,
pub st_blksize: blksize_t,
pub st_blocks: blkcnt_t,
pub st_atim: timespec,
pub st_mtim: timespec,
pub st_ctim: timespec,
pub _pad: [c_char; 24],
}Expand description
Fields
st_dev: dev_tDevice ID of device containing file.
st_ino: ino_tFile serial number.
st_nlink: nlink_tNumber of hard links to the file.
st_mode: mode_tMode of file.
st_uid: uid_tUser ID of file.
st_gid: gid_tGroup ID of file.
st_rdev: dev_tDevice ID (if file is character or block special).
st_size: off_tFor regular files, the file size in bytes. For symbolic links, the length in bytes of the pathname contained in the symbolic link. For a shared or typed memory object, the length in bytes. For other file types, the use of this field is unspecified.
st_blksize: blksize_tA file system-specific preferred I/O block size for this object. In some file system types, this may vary from file to file.
st_blocks: blkcnt_tNumber of blocks allocated for this object.
st_atim: timespecLast data access timestamp.
st_mtim: timespecLast data modification timestamp.
st_ctim: timespecLast file status change timestamp.
_pad: [c_char; 24]Trait Implementations